.. _pyposcar-api-index:

PyPoscar API
===================================

This chapter is intended to describe pyposcar and the analysis of real-space features

PyPoscar has the following data types:

- :class:`pyprocar.pyposcar.Poscar` low-level storage and manipulation of an input crystal structure POSCAR-like format. 
- :class:`pyprocar.pyposcar.poscar_modify` general utility to manipulate a crystal structure. 



.. toctree::
   :maxdepth: 2
   
   poscar
   poscarutils
   
